holcrawl
########

``holcrawl`` is a crawler for building Hollywood movies datsets.

.. code-block:: bash

  holcrawl byyear 2015


.. contents::
.. section-numbering::


Installation
============

``holcrawl`` is tested on Python 3.5.

Install ``holcrawl`` with:

.. code-block:: bash

  pip install holcrawl


Use
===

``holcrawl`` can be controlled using a simple command-line interface. After installation, run

.. code-block:: bash

  holcrawl --help

to get help about the different commands ``holcrawl`` supports.


Credits
=======
Created by Shay Palachy  (shay.palachy@gmail.com).
